@@ -4,7 +4,7 @@
 import sys
 
 
-def string_to_list(strs, spliter=','):
+def string_to_list(strs, spliter=","):
     """Convert the string to list"""
     if isinstance(strs, list):
         str_list = (str(item).strip() for item in strs)
@@ -32,39 +32,16 @@ def form_errors_to_list(form):
 
 
 def request_host_link(request, domain_name=None):
-    protocol = 'https://'
-    if 'runserver' in sys.argv:
-        protocol = 'http://'
+    protocol = "https://"
+    if "runserver" in sys.argv:
+        protocol = "http://"
 
     if request:
         if not domain_name:
             domain_name = request.get_host()
         # default to https if in production and we don't know
-        protocol = 'https://'
+        protocol = "https://"
         if not request.is_secure():
-            protocol = 'http://'
+            protocol = "http://"
 
     return protocol + domain_name
-
-
-# todo: remove this
-def clean_request(request, keys=None):
-    """
-    Clean the request strings
-    """
-    request_contents = request.GET.copy()
-    if not keys:
-        keys = request_contents.keys()
-    cleaned_request = {}
-    for key in keys:
-        key = str(key)
-        if request_contents.get(key):
-            if key in ('order_by', 'from_plan'):
-                continue
-
-            value = request.GET[key]
-            # Convert the value to be list if it's __in filter.
-            if key.endswith('__in') and isinstance(value, str):
-                value = string_to_list(value)
-            cleaned_request[key] = value
-    return cleaned_request
