@@ -9,9 +9,10 @@ from django import forms
 
 class SimpleMDE(forms.Textarea):
     """
-        SimpleMDE widget for Django
+    SimpleMDE widget for Django
     """
-    file_upload_id = 'simplemde-file-upload'
+
+    file_upload_id = "simplemde-file-upload"
 
     def render(self, name, value, attrs=None, renderer=None):
         rendered_string = super().render(name, value, attrs, renderer)
@@ -22,17 +23,20 @@ $(document).ready(function() {
     initSimpleMDE(document.getElementById('%s'), $('#%s'));
 });
 </script>
-""" % (self.file_upload_id, attrs['id'], self.file_upload_id)
+""" % (
+            self.file_upload_id,
+            attrs["id"],
+            self.file_upload_id,
+        )
 
         return rendered_string
 
     class Media:
-        css = {
-            'all': ['simplemde/dist/simplemde.min.css',
-                    'prismjs/themes/prism.css']
-        }
-        js = ['simplemde/dist/simplemde.min.js',
-              'marked/marked.min.js',
-              'prismjs/prism.js',
-              'prismjs/plugins/autoloader/prism-autoloader.min.js',
-              'js/simplemde_security_override.js']
+        css = {"all": ["simplemde/dist/simplemde.min.css", "prismjs/themes/prism.css"]}
+        js = [
+            "simplemde/dist/simplemde.min.js",
+            "marked/marked.min.js",
+            "prismjs/prism.js",
+            "prismjs/plugins/autoloader/prism-autoloader.min.js",
+            "js/simplemde_security_override.js",
+        ]
