@@ -7,13 +7,14 @@ from tcms.issuetracker.base import IntegrationThread
 
 class GitlabThread(IntegrationThread):
     """
-        Execute Gitlab RPC code in a thread!
+    Execute Gitlab RPC code in a thread!
 
-        Executed from the IssueTracker interface methods.
+    Executed from the IssueTracker interface methods.
     """
+
     @staticmethod
     def repo_id(bug_system):
-        return '/'.join(bug_system.base_url.strip().strip('/').split('/')[-2:])
+        return "/".join(bug_system.base_url.strip().strip("/").split("/")[-2:])
 
     def __init__(self, rpc, bug_system, execution, bug_id):
         repo_id = self.repo_id(bug_system)
@@ -22,4 +23,4 @@ class GitlabThread(IntegrationThread):
         super().__init__(rpc, bug_system, execution, bug_id)
 
     def post_comment(self):
-        self.repo.issues.get(self.bug_id).notes.create({'body': self.text()})
+        self.repo.issues.get(self.bug_id).notes.create({"body": self.text()})
