@@ -5,13 +5,11 @@ from modernrpc.core import REQUEST_KEY, rpc_method
 
 from tcms.rpc.decorators import permissions_required
 
-__all__ = (
-    'remove_attachment',
-)
+__all__ = ("remove_attachment",)
 
 
-@permissions_required('attachments.delete_attachment')
-@rpc_method(name='Attachment.remove_attachment')
+@permissions_required("attachments.delete_attachment")
+@rpc_method(name="Attachment.remove_attachment")
 def remove_attachment(attachment_id, **kwargs):
     """
     .. function:: RPC Attachment.remove_attachment(attachment_id)
