@@ -2,12 +2,12 @@
 
 from modernrpc.core import rpc_method
 
-from tcms.testcases.models import Category
 from tcms.rpc.decorators import permissions_required
+from tcms.testcases.models import Category
 
 
-@permissions_required('testcases.view_category')
-@rpc_method(name='Category.filter')
+@permissions_required("testcases.view_category")
+@rpc_method(name="Category.filter")
 def filter(query):  # pylint: disable=redefined-builtin
     """
     .. function:: RPC Category.filter(query)
@@ -19,4 +19,8 @@ def filter(query):  # pylint: disable=redefined-builtin
         :return: List of serialized :class:`tcms.testcases.models.Category` objects
         :rtype: list(dict)
     """
-    return Category.to_xmlrpc(query)
+    return list(
+        Category.objects.filter(**query)
+        .values("id", "name", "product", "description")
+        .distinct()
+    )
