@@ -6,8 +6,8 @@ from tcms.management.models import Priority
 from tcms.rpc.decorators import permissions_required
 
 
-@permissions_required('management.view_priority')
-@rpc_method(name='Priority.filter')
+@permissions_required("management.view_priority")
+@rpc_method(name="Priority.filter")
 def filter(query):  # pylint: disable=redefined-builtin
     """
     .. function:: RPC Priority.filter(query)
@@ -19,4 +19,6 @@ def filter(query):  # pylint: disable=redefined-builtin
         :return: Serialized list of :class:`tcms.management.models.Priority` objects
         :rtype: dict
     """
-    return Priority.to_xmlrpc(query)
+    return list(
+        Priority.objects.filter(**query).values("id", "value", "is_active").distinct()
+    )
