@@ -13,33 +13,29 @@ from tcms.rpc.decorators import permissions_required
 from tcms.testcases.models import TestCase, TestCasePlan
 
 __all__ = (
-    'create',
-    'update',
-    'filter',
-    'sortkeys',
-    'remove',
-
-    'add_comment',
-    'remove_comment',
-
-    'add_component',
-    'comments',
-    'remove_component',
-
-    'add_notification_cc',
-    'get_notification_cc',
-    'remove_notification_cc',
-
-    'add_tag',
-    'remove_tag',
-
-    'add_attachment',
-    'list_attachments',
+    "create",
+    "update",
+    "filter",
+    "history",
+    "sortkeys",
+    "remove",
+    "add_comment",
+    "remove_comment",
+    "add_component",
+    "comments",
+    "remove_component",
+    "add_notification_cc",
+    "get_notification_cc",
+    "remove_notification_cc",
+    "add_tag",
+    "remove_tag",
+    "add_attachment",
+    "list_attachments",
 )
 
 
-@permissions_required('testcases.add_testcasecomponent')
-@rpc_method(name='TestCase.add_component')
+@permissions_required("testcases.add_testcasecomponent")
+@rpc_method(name="TestCase.add_component")
 def add_component(case_id, component):
     """
     .. function:: RPC TestCase.add_component(case_id, component)
@@ -50,7 +46,7 @@ def add_component(case_id, component):
         :type case_id: int
         :param component: Name of Component to add
         :type component: str
-        :return: Serialized :class:`tcms.testcases.models.TestCase` object
+        :return: Serialized :class:`tcms.management.models.Component` object
         :rtype: dict
         :raises PermissionDenied: if missing the *testcases.add_testcasecomponent*
                  permission
@@ -58,14 +54,13 @@ def add_component(case_id, component):
                  specified PKs
     """
     case = TestCase.objects.get(pk=case_id)
-    case.add_component(
-        Component.objects.get(name=component, product=case.category.product)
-    )
-    return case.serialize()
+    component_obj = Component.objects.get(name=component, product=case.category.product)
+    case.add_component(component_obj)
+    return model_to_dict(component_obj)
 
 
-@permissions_required('testcases.delete_testcasecomponent')
-@rpc_method(name='TestCase.remove_component')
+@permissions_required("testcases.delete_testcasecomponent")
+@rpc_method(name="TestCase.remove_component")
 def remove_component(case_id, component_id):
     """
     .. function:: RPC TestCase.remove_component(case_id, component_id)
@@ -88,18 +83,21 @@ def remove_component(case_id, component_id):
 
 def _validate_cc_list(cc_list):
     """
-        Validate each email address given in argument. Called by
-        notification RPC methods.
+    Validate each email address given in argument. Called by
+    notification RPC methods.
 
-        :param cc_list: List of email addresses
-        :type cc_list: list
-        :raises TypeError or ValidationError: if addresses are not valid.
+    :param cc_list: List of email addresses
+    :type cc_list: list
+    :raises TypeError or ValidationError: if addresses are not valid.
     """
 
     if not isinstance(cc_list, list):
-        raise TypeError('cc_list should be a list object.')
+        raise TypeError("cc_list should be a list object.")
 
-    field = EmailField(required=True)
+    field = EmailField(
+        required=True,
+        error_messages={"invalid": "Following email address(es) are invalid: %s"},
+    )
     invalid_emails = []
 
     for item in cc_list:
@@ -110,12 +108,12 @@ def _validate_cc_list(cc_list):
 
     if invalid_emails:
         raise ValidationError(
-            field.error_messages['invalid'] % {
-                'value': ', '.join(invalid_emails)})
+            field.error_messages["invalid"] % ", ".join(invalid_emails)
+        )
 
 
-@permissions_required('testcases.change_testcase')
-@rpc_method(name='TestCase.add_notification_cc')
+@permissions_required("testcases.change_testcase")
+@rpc_method(name="TestCase.add_notification_cc")
 def add_notification_cc(case_id, cc_list):
     """
     .. function:: RPC TestCase.add_notification_cc(case_id, cc_list)
@@ -137,8 +135,8 @@ def add_notification_cc(case_id, cc_list):
     test_case.emailing.add_cc(cc_list)
 
 
-@permissions_required('testcases.change_testcase')
-@rpc_method(name='TestCase.remove_notification_cc')
+@permissions_required("testcases.change_testcase")
+@rpc_method(name="TestCase.remove_notification_cc")
 def remove_notification_cc(case_id, cc_list):
     """
     .. function:: RPC TestCase.remove_notification_cc(case_id, cc_list)
@@ -159,8 +157,8 @@ def remove_notification_cc(case_id, cc_list):
     TestCase.objects.get(pk=case_id).emailing.remove_cc(cc_list)
 
 
-@permissions_required('testcases.view_testcase')
-@rpc_method(name='TestCase.get_notification_cc')
+@permissions_required("testcases.view_testcase")
+@rpc_method(name="TestCase.get_notification_cc")
 def get_notification_cc(case_id):
     """
     .. function:: RPC TestCase.get_notification_cc(case_id)
@@ -171,13 +169,13 @@ def get_notification_cc(case_id):
         :type case_id: int
         :return: List of email addresses
         :rtype: list(str)
-        :raises: TestCase.DoesNotExist if object with case_id doesn't exist
+        :raises TestCase.DoesNotExist: if object with case_id doesn't exist
     """
-    return TestCase.objects.get(pk=case_id).get_cc_list()
+    return TestCase.objects.get(pk=case_id).emailing.get_cc_list()
 
 
-@permissions_required('testcases.add_testcasetag')
-@rpc_method(name='TestCase.add_tag')
+@permissions_required("testcases.add_testcasetag")
+@rpc_method(name="TestCase.add_tag")
 def add_tag(case_id, tag, **kwargs):
     """
     .. function:: RPC TestCase.add_tag(case_id, tag)
@@ -200,8 +198,8 @@ def add_tag(case_id, tag, **kwargs):
     TestCase.objects.get(pk=case_id).add_tag(tag)
 
 
-@permissions_required('testcases.delete_testcasetag')
-@rpc_method(name='TestCase.remove_tag')
+@permissions_required("testcases.delete_testcasetag")
+@rpc_method(name="TestCase.remove_tag")
 def remove_tag(case_id, tag):
     """
     .. function:: RPC TestCase.remove_tag(case_id, tag)
@@ -215,13 +213,11 @@ def remove_tag(case_id, tag):
         :raises PermissionDenied: if missing *testcases.delete_testcasetag* permission
         :raises DoesNotExist: if objects specified don't exist
     """
-    TestCase.objects.get(pk=case_id).remove_tag(
-        Tag.objects.get(name=tag)
-    )
+    TestCase.objects.get(pk=case_id).remove_tag(Tag.objects.get(name=tag))
 
 
-@permissions_required('testcases.add_testcase')
-@rpc_method(name='TestCase.create')
+@permissions_required("testcases.add_testcase")
+@rpc_method(name="TestCase.create")
 def create(values, **kwargs):
     """
     .. function:: RPC TestCase.create(values)
@@ -249,21 +245,23 @@ def create(values, **kwargs):
     """
     request = kwargs.get(REQUEST_KEY)
 
-    if not (values.get('author') or values.get('author_id')):
-        values['author'] = request.user.pk
+    if not (values.get("author") or values.get("author_id")):
+        values["author"] = request.user.pk
 
     form = NewForm(values)
 
     if form.is_valid():
         test_case = form.save()
-    else:
-        raise ValueError(form_errors_to_list(form))
+        result = model_to_dict(test_case, exclude=["component", "plan", "tag"])
+        # b/c date is added in the DB layer and model_to_dict() doesn't return it
+        result["create_date"] = test_case.create_date
+        return result
 
-    return test_case.serialize()
+    raise ValueError(form_errors_to_list(form))
 
 
-@permissions_required('testcases.view_testcase')
-@rpc_method(name='TestCase.filter')
+@permissions_required("testcases.view_testcase")
+@rpc_method(name="TestCase.filter")
 def filter(query=None):  # pylint: disable=redefined-builtin
     """
     .. function:: RPC TestCase.filter(query)
@@ -279,11 +277,59 @@ def filter(query=None):  # pylint: disable=redefined-builtin
     if query is None:
         query = {}
 
-    return TestCase.to_xmlrpc(query)
+    return list(
+        TestCase.objects.filter(**query)
+        .values(
+            "id",
+            "create_date",
+            "is_automated",
+            "script",
+            "arguments",
+            "extra_link",
+            "summary",
+            "requirement",
+            "notes",
+            "text",
+            "case_status",
+            "case_status__name",
+            "category",
+            "category__name",
+            "priority",
+            "priority__value",
+            "author",
+            "author__username",
+            "default_tester",
+            "default_tester__username",
+            "reviewer",
+            "reviewer__username",
+        )
+        .distinct()
+    )
 
 
-@permissions_required('testcases.view_testcase')
-@rpc_method(name='TestCase.sortkeys')
+@permissions_required("testcases.view_testcase")
+@rpc_method(name="TestCase.history")
+def history(case_id, query=None):
+    """
+    .. function:: RPC TestCase.history(case_id, query)
+
+        Return the history for a specified test case.
+
+        :param case_id: TestCase PK
+        :type case_id: int
+        :param query: Field lookups for :class:`tcms.testcases.models.TestCase`
+        :type query: dict
+        :return: Serialized list of HistoricalTestCase objects.
+        :rtype: list(dict)
+    """
+    if query is None:
+        query = {}
+
+    return list(TestCase.objects.get(pk=case_id).history.filter(**query).values())
+
+
+@permissions_required("testcases.view_testcase")
+@rpc_method(name="TestCase.sortkeys")
 def sortkeys(query=None):
     """
     .. function:: RPC TestCase.sortkeys(query)
@@ -309,8 +355,8 @@ def sortkeys(query=None):
     return result
 
 
-@permissions_required('testcases.change_testcase')
-@rpc_method(name='TestCase.update')
+@permissions_required("testcases.change_testcase")
+@rpc_method(name="TestCase.update")
 def update(case_id, values):
     """
     .. function:: RPC TestCase.update(case_id, values)
@@ -332,14 +378,31 @@ def update(case_id, values):
 
     if form.is_valid():
         test_case = form.save()
-    else:
-        raise ValueError(form_errors_to_list(form))
+        result = model_to_dict(test_case, exclude=["component", "plan", "tag"])
+        # b/c date may be None and model_to_dict() doesn't return it
+        result["create_date"] = test_case.create_date
 
-    return test_case.serialize()
+        # additional information
+        result["case_status__name"] = test_case.case_status.name
+        result["category__name"] = test_case.category.name
+        result["priority__value"] = test_case.priority.value
+        result["author__username"] = (
+            test_case.author.username if test_case.author else None
+        )
+        result["default_tester__username"] = (
+            test_case.default_tester.username if test_case.default_tester else None
+        )
+        result["reviewer__username"] = (
+            test_case.reviewer.username if test_case.reviewer else None
+        )
+
+        return result
+
+    raise ValueError(form_errors_to_list(form))
 
 
-@permissions_required('testcases.delete_testcase')
-@rpc_method(name='TestCase.remove')
+@permissions_required("testcases.delete_testcase")
+@rpc_method(name="TestCase.remove")
 def remove(query):
     """
     .. function:: RPC TestCase.remove(query)
@@ -348,7 +411,7 @@ def remove(query):
 
         :param query: Field lookups for :class:`tcms.testcases.models.TestCase`
         :type query: dict
-        :raises: PermissionDenied if missing the *testcases.delete_testcase* permission
+        :raises PermissionDenied: if missing the *testcases.delete_testcase* permission
         :return: The number of objects deleted and a dictionary with the
                  number of deletions per object type.
         :rtype: int, dict
@@ -362,8 +425,8 @@ def remove(query):
     return TestCase.objects.filter(**query).delete()
 
 
-@permissions_required('attachments.view_attachment')
-@rpc_method(name='TestCase.list_attachments')
+@permissions_required("attachments.view_attachment")
+@rpc_method(name="TestCase.list_attachments")
 def list_attachments(case_id, **kwargs):
     """
     .. function:: RPC TestCase.list_attachments(case_id)
@@ -376,15 +439,15 @@ def list_attachments(case_id, **kwargs):
                 entry point name and handler instance from the rpc method
         :return: A list containing information and download URLs for attachements
         :rtype: list
-        :raises: TestCase.DoesNotExit if object specified by PK is missing
+        :raises TestCase.DoesNotExist: if object specified by PK is missing
     """
     case = TestCase.objects.get(pk=case_id)
     request = kwargs.get(REQUEST_KEY)
     return utils.get_attachments_for(request, case)
 
 
-@permissions_required('attachments.add_attachment')
-@rpc_method(name='TestCase.add_attachment')
+@permissions_required("attachments.add_attachment")
+@rpc_method(name="TestCase.add_attachment")
 def add_attachment(case_id, filename, b64content, **kwargs):
     """
     .. function:: RPC TestCase.add_attachment(case_id, filename, b64content)
@@ -402,14 +465,15 @@ def add_attachment(case_id, filename, b64content, **kwargs):
     """
     utils.add_attachment(
         case_id,
-        'testcases.TestCase',
+        "testcases.TestCase",
         kwargs.get(REQUEST_KEY).user,
         filename,
-        b64content)
+        b64content,
+    )
 
 
-@permissions_required('django_comments.add_comment')
-@rpc_method(name='TestCase.add_comment')
+@permissions_required("django_comments.add_comment")
+@rpc_method(name="TestCase.add_comment")
 def add_comment(case_id, comment, **kwargs):
     """
     .. function:: TestCase.add_comment(case_id, comment)
@@ -425,19 +489,22 @@ def add_comment(case_id, comment, **kwargs):
         :return: Serialized :class:`django_comments.models.Comment` object
         :rtype: dict
         :raises PermissionDenied: if missing *django_comments.add_comment* permission
+        :raises TestCase.DoesNotExist: if object specified by PK is missing
 
         .. important::
 
             In webUI comments are only shown **only** during test case review!
     """
     case = TestCase.objects.get(pk=case_id)
-    created = helpers.comments.add_comment([case], comment, kwargs.get(REQUEST_KEY).user)
+    created = helpers.comments.add_comment(
+        [case], comment, kwargs.get(REQUEST_KEY).user
+    )
     # we always create only one comment
     return model_to_dict(created[0])
 
 
-@permissions_required('django_comments.delete_comment')
-@rpc_method(name='TestCase.remove_comment')
+@permissions_required("django_comments.delete_comment")
+@rpc_method(name="TestCase.remove_comment")
 def remove_comment(case_id, comment_id=None):
     """
     .. function:: TestCase.remove_comment(case_id, comment_id)
@@ -449,6 +516,7 @@ def remove_comment(case_id, comment_id=None):
         :param comment_id: PK of a Comment object or None
         :type comment_id: int
         :raises PermissionDenied: if missing *django_comments.delete_comment* permission
+        :raises TestCase.DoesNotExist: if object specified by PK is missing
     """
     case = TestCase.objects.get(pk=case_id)
     to_be_deleted = helpers.comments.get_comments(case)
@@ -458,8 +526,8 @@ def remove_comment(case_id, comment_id=None):
     to_be_deleted.delete()
 
 
-@permissions_required('django_comments.view_comment')
-@rpc_method(name='TestCase.comments')
+@permissions_required("django_comments.view_comment")
+@rpc_method(name="TestCase.comments")
 def comments(case_id):
     """
     .. function:: TestCase.comments(case_id)
@@ -471,6 +539,7 @@ def comments(case_id):
         :return: Serialized list of :class:`django_comments.models.Comment` objects
         :rtype: list
         :raises PermissionDenied: if missing *django_comments.view_comment* permission
+        :raises TestCase.DoesNotExist: if object specified by PK is missing
     """
     case = TestCase.objects.get(pk=case_id)
     result = []
