@@ -11,32 +11,31 @@ from tcms.core.utils import form_errors_to_list
 from tcms.rpc.api.forms.testrun import UpdateExecutionForm
 from tcms.rpc.api.utils import tracker_from_url
 from tcms.rpc.decorators import permissions_required
-from tcms.rpc.serializer import Serializer
 from tcms.testruns.models import TestExecution
 
 # conditional import b/c this App can be disabled
-if 'tcms.bugs.apps.AppConfig' in settings.INSTALLED_APPS:
+if "tcms.bugs.apps.AppConfig" in settings.INSTALLED_APPS:
     from tcms.issuetracker.kiwitcms import KiwiTCMS
 else:
+
     class KiwiTCMS:  # pylint: disable=remove-empty-class,nested-class-found,too-few-public-methods
         pass
 
 
 __all__ = (
-    'update',
-    'filter',
-
-    'add_comment',
-    'remove_comment',
-
-    'add_link',
-    'get_links',
-    'remove_link',
+    "update",
+    "filter",
+    "history",
+    "add_comment",
+    "remove_comment",
+    "add_link",
+    "get_links",
+    "remove_link",
 )
 
 
-@permissions_required('django_comments.add_comment')
-@rpc_method(name='TestExecution.add_comment')
+@permissions_required("django_comments.add_comment")
+@rpc_method(name="TestExecution.add_comment")
 def add_comment(execution_id, comment, **kwargs):
     """
     .. function:: RPC TestExecution.add_comment(execution_id, comment)
@@ -59,11 +58,11 @@ def add_comment(execution_id, comment, **kwargs):
     return model_to_dict(created[0])
 
 
-@permissions_required('django_comments.delete_comment')
-@rpc_method(name='TestExecution.remove_comment')
+@permissions_required("django_comments.delete_comment")
+@rpc_method(name="TestExecution.remove_comment")
 def remove_comment(execution_id, comment_id=None):
     """
-    .. function:: TestExecution.remove_comment(execution_id, comment_id)
+    .. function:: RPC TestExecution.remove_comment(execution_id, comment_id)
 
         Remove all or specified comment(s) from selected test execution.
 
@@ -81,25 +80,93 @@ def remove_comment(execution_id, comment_id=None):
     to_be_deleted.delete()
 
 
-@permissions_required('testruns.view_testexecution')
-@rpc_method(name='TestExecution.filter')
-def filter(values):  # pylint: disable=redefined-builtin
+@permissions_required("django_comments.view_comment")
+@rpc_method(name="TestExecution.get_comments")
+def get_comments(execution_id):
     """
-    .. function:: RPC TestExecution.filter(values)
+    .. function:: RPC TestExecution.get_comments(execution_id)
+
+        Get all comments for selected test execution.
+
+        :param execution_id: PK of a TestExecution object
+        :type execution_id: int
+        :return: Serialized :class:`django_comments.models.Comment` object
+        :rtype: dict
+        :raises PermissionDenied: if missing *django_comments.view_comment* permission
+    """
+    execution = TestExecution.objects.get(pk=execution_id)
+    execution_comments = comments.get_comments(execution).values()
+    return list(execution_comments)
+
+
+@permissions_required("testruns.view_testexecution")
+@rpc_method(name="TestExecution.filter")
+def filter(query):  # pylint: disable=redefined-builtin
+    """
+    .. function:: RPC TestExecution.filter(query)
 
         Perform a search and return the resulting list of test case executions.
 
-        :param values: Field lookups for :class:`tcms.testruns.models.TestExecution`
-        :type values: dict
+        :param query: Field lookups for :class:`tcms.testruns.models.TestExecution`
+        :type query: dict
         :return: List of serialized :class:`tcms.testruns.models.TestExecution` objects
         :rtype: list(dict)
     """
-    return TestExecution.to_xmlrpc(values)
+    return list(
+        TestExecution.objects.filter(**query)
+        .values(
+            "id",
+            "assignee",
+            "assignee__username",
+            "tested_by",
+            "tested_by__username",
+            "case_text_version",
+            "start_date",
+            "stop_date",
+            "sortkey",
+            "run",
+            "case",
+            "case__summary",
+            "build",
+            "build__name",
+            "status",
+            "status__name",
+        )
+        .distinct()
+    )
 
 
-@permissions_required('testruns.change_testexecution')
-@rpc_method(name='TestExecution.update')
-def update(execution_id, values):
+@permissions_required("testruns.view_testexecution")
+@rpc_method(name="TestExecution.history")
+def history(execution_id):
+    """
+    .. function:: RPC TestExecution.history(execution_id)
+
+        Return the history for the selected test execution.
+
+        :param execution_id: PK of a TestExecution object
+        :type execution_id: int
+        :return: List of serialized :class:`tcms.core.history.KiwiHistoricalRecords` objects
+        :rtype: list(dict)
+        :raises PermissionDenied: if missing *testruns.view_testexecution* permission
+    """
+    execution = TestExecution.objects.get(pk=execution_id)
+    execution_history = (
+        execution.history.all()
+        .order_by("-history_date")
+        .values(
+            "history_user__username",
+            "history_change_reason",
+            "history_date",
+            "history_change_reason",
+        )
+    )
+    return list(execution_history)
+
+
+@permissions_required("testruns.change_testexecution")
+@rpc_method(name="TestExecution.update")
+def update(execution_id, values, **kwargs):
     """
     .. function:: RPC TestExecution.update(execution_id, values)
 
@@ -109,6 +176,8 @@ def update(execution_id, values):
         :type execution_id: int
         :param values: Field values for :class:`tcms.testruns.models.TestExecution`
         :type values: dict
+        :param kwargs: Dict providing access to the current request, protocol
+                entry point name and handler instance from the rpc method
         :return: Serialized :class:`tcms.testruns.models.TestExecution` object
         :rtype: dict
         :raises ValueError: if data validations fail
@@ -116,8 +185,14 @@ def update(execution_id, values):
     """
     test_execution = TestExecution.objects.get(pk=execution_id)
 
-    if values.get('case_text_version') == 'latest':
-        values['case_text_version'] = test_execution.case.history.latest().history_id
+    if values.get("case_text_version") == "latest":
+        values["case_text_version"] = test_execution.case.history.latest().history_id
+
+    if values.get("status") and not values.get("tested_by"):
+        values["tested_by"] = kwargs.get(REQUEST_KEY).user.id
+
+    if values.get("status") and not values.get("build"):
+        values["build"] = test_execution.run.build.pk
 
     form = UpdateExecutionForm(values, instance=test_execution)
 
@@ -127,18 +202,43 @@ def update(execution_id, values):
         raise ValueError(form_errors_to_list(form))
 
     # if this call updated TE.status then adjust timestamps
-    if values.get('status'):
+    if values.get("status"):
+        now = timezone.now()
         if test_execution.status.weight != 0:
-            test_execution.close_date = timezone.now()
+            test_execution.stop_date = now
         else:
-            test_execution.close_date = None
+            test_execution.stop_date = None
         test_execution.save()
 
-    return test_execution.serialize()
+        all_executions = TestExecution.objects.filter(run=test_execution.run)
+        if (
+            test_execution.status.weight != 0
+            and not all_executions.filter(status__weight=0).exists()
+        ):
+            test_execution.run.stop_date = now
+            test_execution.run.save()
+        elif test_execution.status.weight == 0 and test_execution.run.stop_date:
+            test_execution.run.stop_date = None
+            test_execution.run.save()
+
+    result = model_to_dict(test_execution)
+
+    # augment result with additional information
+    result["assignee__username"] = (
+        test_execution.assignee.username if test_execution.assignee else None
+    )
+    result["tested_by__username"] = (
+        test_execution.tested_by.username if test_execution.tested_by else None
+    )
+    result["case__summary"] = test_execution.case.summary
+    result["build__name"] = test_execution.build.name
+    result["status__name"] = test_execution.status.name
+
+    return result
 
 
-@permissions_required('linkreference.add_linkreference')
-@rpc_method(name='TestExecution.add_link')
+@permissions_required("linkreference.add_linkreference")
+@rpc_method(name="TestExecution.add_link")
 def add_link(values, update_tracker=False, **kwargs):
     """
     .. function:: RPC TestExecution.add_link(values)
@@ -167,17 +267,19 @@ def add_link(values, update_tracker=False, **kwargs):
     request = kwargs.get(REQUEST_KEY)
     tracker = tracker_from_url(link.url, request)
 
-    if (link.is_defect and
-            update_tracker and
-            not tracker.is_adding_testcase_to_issue_disabled()) or \
-            isinstance(tracker, KiwiTCMS):
+    if (
+        link.is_defect
+        and tracker is not None
+        and update_tracker
+        and not tracker.is_adding_testcase_to_issue_disabled()
+    ) or isinstance(tracker, KiwiTCMS):
         tracker.add_testexecution_to_issue([link.execution], link.url)
 
     return response
 
 
-@permissions_required('linkreference.delete_linkreference')
-@rpc_method(name='TestExecution.remove_link')
+@permissions_required("linkreference.delete_linkreference")
+@rpc_method(name="TestExecution.remove_link")
 def remove_link(query):
     """
     .. function:: RPC TestExecution.remove_link(query)
@@ -191,8 +293,8 @@ def remove_link(query):
     LinkReference.objects.filter(**query).delete()
 
 
-@permissions_required('linkreference.view_linkreference')
-@rpc_method(name='TestExecution.get_links')
+@permissions_required("linkreference.view_linkreference")
+@rpc_method(name="TestExecution.get_links")
 def get_links(query):
     """
     .. function:: RPC TestExecution.get_links(query)
@@ -206,6 +308,13 @@ def get_links(query):
                  objects
         :rtype: dict
     """
-    links = LinkReference.objects.filter(**query)
-    serialier = Serializer(links)
-    return serialier.serialize_queryset()
+    return list(
+        LinkReference.objects.filter(**query).values(
+            "id",
+            "name",
+            "url",
+            "execution",
+            "created_on",
+            "is_defect",
+        )
+    )
