@@ -1,21 +1,21 @@
 # -*- coding: utf-8 -*-
 
+from django.forms.models import model_to_dict
 from modernrpc.core import rpc_method
 
 from tcms.core.utils import form_errors_to_list
 from tcms.management.forms import VersionForm
 from tcms.management.models import Version
 from tcms.rpc.decorators import permissions_required
-from tcms.rpc.utils import pre_check_product
 
 __all__ = (
-    'create',
-    'filter',
+    "create",
+    "filter",
 )
 
 
-@permissions_required('management.view_version')
-@rpc_method(name='Version.filter')
+@permissions_required("management.view_version")
+@rpc_method(name="Version.filter")
 def filter(query):  # pylint: disable=redefined-builtin
     """
     .. function:: RPC Version.filter(query)
@@ -27,11 +27,13 @@ def filter(query):  # pylint: disable=redefined-builtin
         :return: List of serialized :class:`tcms.management.models.Version` objects
         :rtype: list(dict)
     """
-    return Version.to_xmlrpc(query)
+    return list(
+        Version.objects.filter(**query).values("id", "value", "product").distinct()
+    )
 
 
-@permissions_required('management.add_version')
-@rpc_method(name='Version.create')
+@permissions_required("management.add_version")
+@rpc_method(name="Version.create")
 def create(values):
     """
     .. function:: RPC Version.create(values)
@@ -49,14 +51,11 @@ def create(values):
 
         # Add version for specified product:
         >>> Version.create({'value': 'devel', 'product': 272})
-        {'product': 'QE Test Product', 'id': '1106', 'value': 'devel', 'product_id': 272}
+        {'id': '1106', 'value': 'devel', 'product': 272}
     """
-    product = pre_check_product(values)
-    form_values = values.copy()
-    form_values['product'] = product.pk
-
-    form = VersionForm(form_values)
+    form = VersionForm(values)
     if form.is_valid():
         version = form.save()
-        return version.serialize()
+        return model_to_dict(version)
+
     raise ValueError(form_errors_to_list(form))
