@@ -31,6 +31,9 @@ function updateSelect(data, selector, id_attr, value_attr) {
 function update_version_select_from_product() {
     var updateVersionSelectCallback = function(data) {
         updateSelect(data, '#id_version', 'id', 'value')
+
+        // trigger on-change handler, possibly updating build
+        $('#id_version').change()
     };
 
     var product_id = $('#id_product').val();
@@ -44,7 +47,7 @@ function update_version_select_from_product() {
 /*
     Used for on-change event handlers
 */
-function update_build_select_from_product(keep_first) {
+function update_build_select_from_version(keep_first) {
     var updateCallback = function(data) {
         updateSelect(data, '#id_build', 'id', 'name')
     }
@@ -55,9 +58,9 @@ function update_build_select_from_product(keep_first) {
         $('#id_build').find('option').remove();
     }
 
-    var product_id = $('#id_product').val();
-    if (product_id) {
-        jsonRPC('Build.filter', {product: product_id}, updateCallback);
+    const version_id = $('#id_version').val();
+    if (version_id) {
+        jsonRPC('Build.filter', {version: version_id}, updateCallback);
     } else {
         updateCallback([]);
     }
@@ -176,10 +179,15 @@ function treeViewBind(selector = '.tree-list-view-pf') {
 }
 
 const animate = (target, handler, time = 500) => target.fadeOut(time, handler).fadeIn(time)
+const currentTimeWithTimezone = timeZone => moment().tz(timeZone).format('YYYY-MM-DD HH:mm:ss')
 
 
 /* render Markdown & assign it to selector */
 function markdown2HTML(input, selector) {
+    // first display raw input in case user is not logged in and
+    // Markdown.render returns 403 forbidden
+    $(selector).html(input);
+
     jsonRPC('Markdown.render', unescapeHTML(input), function(result) {
         $(selector).html(unescapeHTML(result));
     });
@@ -226,26 +234,168 @@ function renderCommentsForObject(objId, getMethod, deleteMethod, canDelete, pare
     })
 }
 
-function filterTestCasesByProperty(planId, testCases, filterBy, filterValue) {
-    // no input => show all rows
-    if (filterValue.trim().length === 0) {
-        $('.js-testcase-row').show();
-        return;
-    }
-
-    $('.js-testcase-row').hide();
-    if (filterBy === 'component' || filterBy === 'tag') {
-        let query = {plan: planId}
-        query[`${filterBy}__name__icontains`] = filterValue
-
-        jsonRPC('TestCase.filter', query, function(filtered) {
-            // hide again if a previous async request showed something else
-            $('.js-testcase-row').hide();
-            filtered.forEach(tc => $(`[data-testcase-pk=${tc.id}]`).show());
-        })
+function showPopup(href) {
+    if (href.indexOf('?') === -1) {
+        href += '?nonav=1';
     } else {
-        testCases.filter(function(tc){
-            return (tc[filterBy] && tc[filterBy].toString().toLowerCase().indexOf(filterValue) > -1)
-        }).forEach(tc => $(`[data-testcase-pk=${tc.id}]`).show());
+        href += '&nonav=1';
     }
+
+    const win = window.open(href, 'popup page', 'width=1024,height=612');
+    win.focus();
+
+    return win;
+}
+
+// used in testplans/get.html and testruns/get.html
+// objId - PK of the object we're adding to
+// rpcMethod - must accept [pk, case_id] - the method used to do the work
+// href - URL of the search page
+// errorMessage - message to display in case of RPC errors
+function advancedSearchAndAddTestCases(objId, rpcMethod, href, errorMessage) {
+    $('#popup-selection').val('');
+
+    if (href.indexOf('?') === -1) {
+        href += '?allow_select=1';
+    } else {
+        href += '&allow_select=1';
+    }
+
+    let rpcErrors = 0,
+        testCaseIDs = [];
+    popupWindow = showPopup(href);
+
+    $(popupWindow).on('beforeunload', function(){
+        testCaseIDs = $('#popup-selection').val();
+
+        if (testCaseIDs) {
+            // monkey-patch the alert() function
+            const oldAlert = window.alert;
+            alert = window.alert = function(message) {
+                rpcErrors += 1;
+            }
+
+            // add the selected test cases
+            testCaseIDs.split(",").forEach(function(testCase) {
+                jsonRPC(rpcMethod, [objId, testCase], function(result) {}, true)
+            })
+
+            // revert monkey-patch
+            alert = window.alert = oldAlert;
+        }
+    });
+
+    $(popupWindow).on('unload', function(){
+        let message;
+
+        if (rpcErrors) {
+            alert(errorMessage);
+        }
+
+        // something was added so reload the page
+        if (testCaseIDs.length > rpcErrors) {
+            window.location.reload(true);
+            // TODO: figure out how to reload above and add the new value to the page
+        }
+    });
+
+    return false;
+}
+
+// used in both testplans/get.html and testruns/get.html to initialize and
+// handle the quicksearch widget
+// objId - PK of the object we're adding to
+// pageCallback - function which performs the actual RPC call of adding
+//                the selected TC to objId and refreshes the page
+// cache - cache of previous values fetched for typeahead
+// initialQuery - an initial RPC query that is AND'ed to the internal conditions
+//                for example: filter only CONFIRMED TCs.
+function quickSearchAndAddTestCase(objId, pageCallback, cache, initialQuery = {}) {
+    // + button
+    $('#btn-add-case').click(function() {
+        pageCallback(objId)
+
+        return false
+    });
+
+    // Enter key
+    $('#search-testcase').keyup(function(event) {
+        if (event.keyCode === 13) {
+            pageCallback(objId)
+
+            return false
+        };
+    });
+
+    // autocomplete
+    $('#search-testcase.typeahead').typeahead({
+        minLength: 1,
+        highlight: true
+        }, {
+        name: 'testcases-autocomplete',
+        // will display up to X results even if more were returned
+        limit: 100,
+        async: true,
+        display: function(element) {
+            const displayName = `TC-${element.id}: ${element.summary}`;
+            cache[displayName] = element;
+            return displayName;
+        },
+        source: function(query, processSync, processAsync) {
+            // accepts "TC-1234" or "tc-1234" or "1234"
+            query = query.toLowerCase().replace('tc-', '');
+            if (query === '') {
+                return;
+            }
+
+            var rpc_query = {pk: query};
+
+            // or arbitrary string
+            if (isNaN(query)) {
+                if (query.length >=3) {
+                    rpc_query = {summary__icontains: query};
+                } else {
+                    return;
+                }
+            }
+
+            // merge initial query for more filtering if specified
+            rpc_query = Object.assign({}, rpc_query, initialQuery)
+
+            jsonRPC('TestCase.filter', rpc_query, function(data) {
+                return processAsync(data);
+            });
+        }
+    });
+}
+
+// on dropdown change update the label of the button and set new selected list item
+function changeDropdownSelectedItem(dropDownSelector, buttonSelector, target, focusTarget) {
+    $(`${buttonSelector}`)[0].innerHTML = target.innerText + '<span class="caret"></span>';
+
+    //remove selected class
+    $(`${dropDownSelector} li`).each(function(index, el) {
+        el.className = '';
+    });
+
+    // target is a tag
+    target.parentElement.className = 'selected';
+
+    // close the parent menu
+    $(target).parents('.open').toggleClass('open')
+
+    // clear the text & the current filter
+    if (focusTarget) {
+        focusTarget.val('').keyup().focus();
+    }
+
+    // don't follow links
+    return false;
+}
+
+function arrayToDict(arr) {
+    return arr.reduce(function(map, obj) {
+        map[obj.id] = obj;
+        return map;
+    }, {});
 }
