@@ -2,7 +2,7 @@ from django.db import migrations
 
 
 def forwards(apps, schema_editor):
-    bug_system_model = apps.get_model('testcases', 'BugSystem')
+    bug_system_model = apps.get_model("testcases", "BugSystem")
 
     for record in bug_system_model.objects.all():
         if record.tracker_type:
@@ -11,18 +11,20 @@ def forwards(apps, schema_editor):
 
 
 def backwards(apps, schema_editor):
-    bug_system_model = apps.get_model('testcases', 'BugSystem')
+    bug_system_model = apps.get_model("testcases", "BugSystem")
 
     for record in bug_system_model.objects.all():
-        if record.tracker_type.startswith('tcms.issuetracker.types.'):
-            record.tracker_type = record.tracker_type.replace('tcms.issuetracker.types.', '')
+        if record.tracker_type.startswith("tcms.issuetracker.types."):
+            record.tracker_type = record.tracker_type.replace(
+                "tcms.issuetracker.types.", ""
+            )
             record.save()
 
 
 class Migration(migrations.Migration):
 
     dependencies = [
-        ('testcases', '0013_remove_autofield'),
+        ("testcases", "0013_remove_autofield"),
     ]
 
     operations = [
