@@ -1,4 +1,3 @@
-const bug_details_cache = {}
 const plan_cache = {}
 
 
@@ -8,7 +7,7 @@ function addComponent(object_id, _input, to_table) {
     if (_name.length > 0) {
         jsonRPC('TestCase.add_component', [object_id, _name], function(data) {
             if (data !== undefined) {
-                to_table.row.add({name: _name}).draw();
+                to_table.row.add({name: data.name, id: data.id}).draw();
                 $(_input).val('');
             } else {
                 $(_input).parents('div.input-group').addClass('has-error');
@@ -26,9 +25,9 @@ function addTestPlanToTestCase(case_id, plans_table) {
         plans_table.row.add({
             id: plan.id,
             name: plan.name,
-            author: plan.author,
-            type: plan.type,
-            product: plan.product
+            author__username: plan.author__username,
+            type__name: plan.type__name,
+            product__name: plan.product__name
         }).draw();
         $('#input-add-plan').val('');
     });
@@ -107,11 +106,11 @@ $(document).ready(function() {
         columns: [
             { data: "name" },
             {
-                data: null,
+                data: "id",
                 sortable: false,
                 render: function (data, type, full, meta) {
                     if (perm_remove_component) {
-                        return '<a href="#components" class="remove-component" data-pk="' + data.id  + '"><span class="pficon-error-circle-o"></span></a>';
+                        return '<a href="#components" class="remove-component" data-pk="' + data  + '"><span class="pficon-error-circle-o"></span></a>';
                     }
                     return '';
                 }
@@ -170,7 +169,7 @@ $(document).ready(function() {
     // testplans table
     var plans_table = $('#plans').DataTable({
         ajax: function(data, callback, settings) {
-            dataTableJsonRPC('TestPlan.filter', {case: case_id}, callback);
+            dataTableJsonRPC('TestPlan.filter', {cases: case_id}, callback);
         },
         columns: [
             { data: "id" },
@@ -180,9 +179,9 @@ $(document).ready(function() {
                     return '<a href="/plan/'+ data.id + '/">' + escapeHTML(data.name) + '</a>';
                 }
             },
-            { data: "author" },
-            { data: "type"},
-            { data: "product" },
+            { data: "author__username" },
+            { data: "type__name" },
+            { data: "product__name" },
             {
                 data: null,
                 sortable: false,
@@ -218,76 +217,11 @@ $(document).ready(function() {
     initAddPlan(case_id, plans_table);
 
     // bugs table
-    $('#bugs').DataTable({
-        ajax: function(data, callback, settings) {
-            dataTableJsonRPC('TestExecution.get_links',
-                             {execution__case: case_id,
-                              is_defect: true}, callback);
-        },
-        columns: [
-            {
-                data: null,
-                render: function (data, type, full, meta) {
-                    return '<a href="' + data.url + '" class="bug-url">' + data.url + '</a>';
-                }
-            },
-            {
-                data: null,
-                render: function (data, type, full, meta) {
-                    return '<a href="#bugs" data-toggle="popover" data-html="true" ' +
-                                'data-content="undefined" data-trigger="focus" data-placement="top">' +
-                                '<span class="fa fa-info-circle"></span>' +
-                           '</a>';
-                }
-            },
-        ],
-        dom: "t",
-        language: {
-            loadingRecords: '<div class="spinner spinner-lg"></div>',
-            processing: '<div class="spinner spinner-lg"></div>',
-            zeroRecords: "No records found"
-        },
-        order: [[ 0, 'asc' ]],
-    });
-
-    $('#bugs').on('draw.dt', function () {
-        $('#bugs').find('[data-toggle=popover]')
-        .popovers()
-        .on('show.bs.popover', function(element) {
-            fetchBugDetails($(element.target).parents('tr').find('.bug-url')[0],
-                            element.target,
-                            bug_details_cache);
-        });
-    });
-
-    $('[data-toggle=popover]')
-        .popovers()
-        .on('show.bs.popover', function(element) {
-            fetchBugDetails($(element.target).parents('.list-view-pf-body').find('.bug-url')[0],
-                            element.target,
-                            bug_details_cache);
-    });
+    loadBugs('.bugs', {
+        execution__case: case_id,
+        is_defect: true
+    })
 
     // executions treeview
     treeViewBind();
 });
-
-
-function assignPopoverData(source, popover, data) {
-    source.title = data.title;
-    $(popover).attr('data-original-title', data.title);
-    $(popover).attr('data-content', data.description);
-}
-
-
-function fetchBugDetails(source, popover, cache) {
-    if (source.href in cache) {
-        assignPopoverData(source, popover, cache[source.href]);
-        return;
-    }
-
-    jsonRPC('Bug.details', [source.href], function(data) {
-        cache[source.href] = data;
-        assignPopoverData(source, popover, data);
-    }, true);
-}
