@@ -1,11 +1,55 @@
-function pre_process_data(data) {
-    var component_cache = {};
-    var tags_cache = {};
-
+function pre_process_data(data, callback) {
+    const caseIds = []
     data.forEach(function(element) {
-        addResourceToData(element, 'component', 'Component.filter', component_cache);
-        addResourceToData(element, 'tag', 'Tag.filter', tags_cache);
-    });
+        caseIds.push(element.id)
+    })
+
+    // get tags for all objects
+    const tagsPerCase = {}
+    jsonRPC('Tag.filter', {case__in: caseIds}, function(tags) {
+        tags.forEach(function(element) {
+            if (tagsPerCase[element.case] === undefined) {
+                tagsPerCase[element.case] = []
+            }
+
+            // push only if unique
+            if (tagsPerCase[element.case].indexOf(element.name) === -1) {
+                tagsPerCase[element.case].push(element.name)
+            }
+        })
+
+        // get components for all objects
+        const componentsPerCase = {}
+        jsonRPC('Component.filter', {cases__in: caseIds}, function(components) {
+            components.forEach(function(element) {
+                if (componentsPerCase[element.cases] === undefined) {
+                    componentsPerCase[element.cases] = []
+                }
+
+                // push only if unique
+                if (componentsPerCase[element.cases].indexOf(element.name) === -1) {
+                    componentsPerCase[element.cases].push(element.name)
+                }
+            })
+
+            // augment data set with additional info
+            data.forEach(function(element) {
+                if (element.id in tagsPerCase) {
+                    element.tag_names = tagsPerCase[element.id]
+                } else {
+                    element.tag_names = []
+                }
+
+                if (element.id in componentsPerCase) {
+                    element.component_names = componentsPerCase[element.id]
+                } else {
+                    element.component_names = []
+                }
+            });
+
+            callback({data: data}) // renders everything
+        })
+    })
 }
 
 
@@ -82,7 +126,7 @@ $(document).ready(function() {
                 target: 1,
                 className: 'js-select-checkbox',
                 render: function (data, type, full, meta) {
-                    return `<input type="checkbox" value="${data.id}">`;
+                    return `<input type="checkbox" value="${data.id}" name="row-check">`;
                 }
             },
             { data: "id" },
@@ -93,19 +137,13 @@ $(document).ready(function() {
                 }
             },
             { data: "create_date"},
-            { data: "category"},
-            {
-                data: "component",
-                render: renderFromCache,
-            },
-            { data: "priority" },
-            { data: "case_status"},
+            { data: "category__name"},
+            { data: "component_names" },
+            { data: "priority__value" },
+            { data: "case_status__name"},
             { data: "is_automated" },
-            { data: "author" },
-            {
-                data: "tag",
-                render: renderFromCache,
-            },
+            { data: "author__username" },
+            { data: "tag_names" },
         ],
         dom: "t",
         language: {
@@ -118,6 +156,29 @@ $(document).ready(function() {
 
     hookIntoPagination('#resultsTable', table);
 
+    const selectAllButton = $("#check-all")
+
+    selectAllButton.click(function () {
+        const rowCheckboxInputButton = $("input:checkbox[name='row-check']")
+        const isChecked = selectAllButton.prop("checked")
+        rowCheckboxInputButton.prop("checked", isChecked)
+        isChecked ? table.rows().select() : table.rows().deselect()
+    });
+
+    table.on('select', function (e, dt, type, indexes) {
+        if (type === 'row') {
+            const totalRows = $("input:checkbox[name='row-check']").length;
+            const selectedRows = $("input:checkbox[name='row-check']:checked").length;
+            selectAllButton.prop("checked", totalRows === selectedRows)
+        }
+    });
+
+    table.on('deselect', function (e, dt, type, indexes) {
+        if (type === 'row') {
+            selectAllButton.prop("checked", false)
+        } 
+    });
+
     $('#select-btn').click(function(event){
         event.preventDefault();
         let testCaseIDs = [];
@@ -140,9 +201,11 @@ $(document).ready(function() {
     });
 
     $('#id_product').change(function() {
+        // todo: this is duplicate with update_category_from_product()
         var updateCategory = function(data) {
             updateSelect(data, '#id_category', 'id', 'name');
         }
+        // todo: this is duplicate with update_component_from_product()
         var updateComponent = function(data) {
             updateSelect(data, '#id_component', 'id', 'name');
         }
