@@ -3,13 +3,15 @@ from django.apps import AppConfig as DjangoAppConfig
 
 
 class AppConfig(DjangoAppConfig):
-    name = 'tcms.testplans'
+    name = "tcms.testplans"
 
     def ready(self):
         from django.db.models.signals import post_save, pre_delete, pre_save
-        from .models import TestPlan
+
         from tcms import signals
 
+        from .models import TestPlan
+
         pre_save.connect(signals.pre_save_clean, TestPlan)
         post_save.connect(signals.handle_emails_post_plan_save, TestPlan)
         post_save.connect(signals.handle_attachments_post_save, sender=TestPlan)
