@@ -4,81 +4,58 @@ var expandedTestCaseIds = [],
 const allTestCases = {},
       autocomplete_cache = {};
 
+let confirmedStatuses = [];
+
 
 $(document).ready(function() {
-    const testPlanId = $('#test_plan_pk').data('testplan-pk');
+    const testPlanDataElement = $('#test_plan_pk');
+    const testPlanId = testPlanDataElement.data('testplan-pk');
 
     const permissions = {
-        'perm-change-testcase': $('#test_plan_pk').data('perm-change-testcase') === 'True',
-        'perm-remove-testcase': $('#test_plan_pk').data('perm-remove-testcase') === 'True',
-        'perm-add-testcase': $('#test_plan_pk').data('perm-add-testcase') === 'True',
-        'perm-add-comment': $('#test_plan_pk').data('perm-add-comment') === 'True',
-        'perm-delete-comment': $('#test_plan_pk').data('perm-delete-comment') === 'True'
+        'perm-change-testcase': testPlanDataElement.data('perm-change-testcase') === 'True',
+        'perm-remove-testcase': testPlanDataElement.data('perm-remove-testcase') === 'True',
+        'perm-add-testcase': testPlanDataElement.data('perm-add-testcase') === 'True',
+        'perm-add-comment': testPlanDataElement.data('perm-add-comment') === 'True',
+        'perm-delete-comment': testPlanDataElement.data('perm-delete-comment') === 'True'
     };
 
-    $('#btn-search-cases').click(function () {
-        return searchAndSelectTestCases(testPlanId, $(this).attr('href'));
-    });
-
     // bind everything in tags table
-    const perm_remove_tag = $('#test_plan_pk').data('perm-remove-tag') === 'True';
+    const perm_remove_tag = testPlanDataElement.data('perm-remove-tag') === 'True';
     tagsCard('TestPlan', testPlanId, {plan: testPlanId}, perm_remove_tag);
 
-    jsonRPC('TestCase.sortkeys', {'plan': testPlanId}, function(sortkeys) {
-        jsonRPC('TestCase.filter', {'plan': testPlanId}, function(data) {
-            for (var i = 0; i < data.length; i++) {
-                var testCase = data[i];
+    jsonRPC('TestCaseStatus.filter', {is_confirmed: true}, function(statuses) {
+        // save for later use
+        for (let i = 0; i < statuses.length; i++) {
+            confirmedStatuses.push(statuses[i].id);
+        }
 
-                testCase.sortkey = sortkeys[testCase.id];
-                allTestCases[testCase.id] = testCase;
-            }
-            sortTestCases(Object.values(allTestCases), testPlanId, permissions, 'sortkey');
+        jsonRPC('TestCase.sortkeys', {'plan': testPlanId}, function(sortkeys) {
+            jsonRPC('TestCase.filter', {'plan': testPlanId}, function(data) {
+                for (var i = 0; i < data.length; i++) {
+                    var testCase = data[i];
 
-            // drag & reorder needs the initial order of test cases and
-            // they may not be fully loaded when sortable() is initialized!
-            toolbarEvents(testPlanId, permissions);
+                    testCase.sortkey = sortkeys[testCase.id];
+                    allTestCases[testCase.id] = testCase;
+                }
+                sortTestCases(Object.values(allTestCases), testPlanId, permissions, 'sortkey');
+
+                // drag & reorder needs the initial order of test cases and
+                // they may not be fully loaded when sortable() is initialized!
+                toolbarEvents(testPlanId, permissions);
+            });
         });
     });
 
     adjustTestPlanFamilyTree();
     collapseDocumentText();
-    initTestCaseSearchAndAdd(testPlanId);
-});
-
-
-function searchAndSelectTestCases(planId, href) {
-    $('#popup-selection').val('');
-    popupWindow = showPopup(`${href}?allow_select=1`);
-
-    $(popupWindow).on('beforeunload', function(){
-        const testCaseIDs = $('#popup-selection').val();
-
-        if (testCaseIDs) {
-            // add the selected test cases
-            testCaseIDs.split(",").forEach(function(testCase) {
-                jsonRPC('TestPlan.add_case', [planId, testCase], function(result) {}, true)
-            })
-
-            window.location.reload(true);
-            // TODO: remove the page reload above and add the new case to the list
-        }
+    quickSearchAndAddTestCase(testPlanId, addTestCaseToPlan, autocomplete_cache);
+    $('#btn-search-cases').click(function () {
+        return advancedSearchAndAddTestCases(
+            testPlanId, 'TestPlan.add_case', $(this).attr('href'),
+            $('#test_plan_pk').data('trans-error-adding-cases')
+        );
     });
-
-    return false;
-}
-
-function showPopup(href) {
-    if (href.indexOf('?') === -1) {
-        href += '?nonav=1';
-    } else {
-        href += '&nonav=1';
-    }
-
-    const win = window.open(href, 'popup page', 'width=1024,height=612');
-    win.focus();
-
-    return win;
-}
+});
 
 function addTestCaseToPlan(planId) {
     const caseName = $('#search-testcase')[0].value;
@@ -102,65 +79,6 @@ function addTestCaseToPlan(planId) {
     });
 }
 
-
-function initTestCaseSearchAndAdd(planId) {
-    // + button
-    $('#btn-add-case').click(function() {
-        addTestCaseToPlan(planId);
-
-        return false;
-    });
-
-    // Enter key
-    $('#search-testcase').keyup(function(event) {
-        if (event.keyCode === 13) {
-            addTestCaseToPlan(planId);
-
-            return false;
-        };
-    });
-
-    // autocomplete
-    $('#search-testcase.typeahead').typeahead({
-        minLength: 1,
-        highlight: true
-        }, {
-        name: 'testcases-autocomplete',
-        // will display up to X results even if more were returned
-        limit: 100,
-        async: true,
-        display: function(element) {
-            const displayName = `TC-${element.id}: ${element.summary}`;
-            autocomplete_cache[displayName] = element;
-            return displayName;
-        },
-        source: function(query, processSync, processAsync) {
-            // accepts "TC-1234" or "tc-1234" or "1234"
-            query = query.toLowerCase().replace('tc-', '');
-            if (query === '') {
-                return;
-            }
-
-            var rpc_query = {pk: query};
-
-            // or arbitrary string
-            if (isNaN(query)) {
-                if (query.length >=3) {
-                    rpc_query = {summary__icontains: query};
-                } else {
-                    return;
-                }
-            }
-
-            jsonRPC('TestCase.filter', rpc_query, function(data) {
-                return processAsync(data);
-            });
-        }
-    });
-}
-
-
-
 function collapseDocumentText() {
     // for some reason .height() reports a much higher value than
     // reality and the 59% reduction seems to work nicely
@@ -222,6 +140,9 @@ function redrawSingleRow(testCaseId, testPlanId, permissions) {
     var testCaseRowDocumentFragment = $('#test_case_row')[0].content,
         newRow = getTestCaseRowContent(testCaseRowDocumentFragment.cloneNode(true), allTestCases[testCaseId], permissions);
 
+    // remove from expanded list b/c the comment section may have changed
+    delete expandedTestCaseIds[expandedTestCaseIds.indexOf(testCaseId)];
+
     // replace the element in the dom
     $(`[data-testcase-pk=${testCaseId}]`).replaceWith(newRow);
     attachEvents(testPlanId, permissions);
@@ -234,12 +155,12 @@ function getTestCaseRowContent(rowContent, testCase, permissions) {
     row.find('.js-test-case-link').html(`TC-${testCase.id}: ${testCase.summary}`).attr('href', `/case/${testCase.id}/`);
     // todo: TestCaseStatus here isn't translated b/c TestCase.filter uses a
     // custom serializer which needs to be refactored as well
-    row.find('.js-test-case-status').html(`${testCase.case_status}`);
-    row.find('.js-test-case-priority').html(`${testCase.priority}`);
-    row.find('.js-test-case-category').html(`${testCase.category}`);
-    row.find('.js-test-case-author').html(`${testCase.author}`);
-    row.find('.js-test-case-tester').html(`${testCase.default_tester || '-'}`);
-    row.find('.js-test-case-reviewer').html(`${testCase.reviewer || '-'}`);
+    row.find('.js-test-case-status').html(`${testCase.case_status__name}`);
+    row.find('.js-test-case-priority').html(`${testCase.priority__value}`);
+    row.find('.js-test-case-category').html(`${testCase.category__name}`);
+    row.find('.js-test-case-author').html(`${testCase.author__username}`);
+    row.find('.js-test-case-tester').html(`${testCase.default_tester__username || '-'}`);
+    row.find('.js-test-case-reviewer').html(`${testCase.reviewer__username || '-'}`);
 
     // set the links in the kebab menu
     if (permissions['perm-change-testcase']) {
@@ -252,7 +173,7 @@ function getTestCaseRowContent(rowContent, testCase, permissions) {
 
     // apply visual separation between confirmed and not confirmed
 
-    if (!isTestCaseConfirmed(testCase.case_status_id)) {
+    if (!isTestCaseConfirmed(testCase.case_status)) {
         row.find('.list-group-item-header').addClass('bg-danger');
 
         // add customizable icon as part of #1932
@@ -332,10 +253,16 @@ function getTestCaseExpandArea(row, testCase, permissions) {
     // load tags
     const tagTemplate = row.find('.js-testcase-expand-tags').find('template')[0].content;
     jsonRPC('Tag.filter', {case: testCase.id}, function(result) {
+        const uniqueTags = []
+
         result.forEach(function(element) {
-            const newTag = tagTemplate.cloneNode(true);
-            $(newTag).find('span').html(element.name);
-            row.find('.js-testcase-expand-tags').append(newTag);
+            if (uniqueTags.indexOf(element.name) === -1) {
+                uniqueTags.push(element.name)
+
+                const newTag = tagTemplate.cloneNode(true);
+                $(newTag).find('span').html(element.name);
+                row.find('.js-testcase-expand-tags').append(newTag);
+            }
         });
     });
 
@@ -344,13 +271,13 @@ function getTestCaseExpandArea(row, testCase, permissions) {
         testCase.id,
         'TestCase.comments',
         'TestCase.remove_comment',
-        !isTestCaseConfirmed(testCase.case_status_id) && permissions['perm-delete-comment'],
+        !isTestCaseConfirmed(testCase.case_status) && permissions['perm-delete-comment'],
         row.find('.comments'),
     )
 
     // render comments form
     const commentFormTextArea = row.find('.js-comment-form-textarea');
-    if (!isTestCaseConfirmed(testCase.case_status_id) && permissions['perm-add-comment']) {
+    if (!isTestCaseConfirmed(testCase.case_status) && permissions['perm-add-comment']) {
         const textArea = row.find('textarea')[0];
         const fileUpload = row.find('input[type="file"]')
         const editor = initSimpleMDE(textArea, $(fileUpload), textArea.id)
@@ -418,9 +345,6 @@ function attachEvents(testPlanId, permissions) {
             const testCaseId = getCaseIdFromEvent(ev);
             updateTestCasesViaAPI([testCaseId], {case_status: ev.target.dataset.id},
                                   testPlanId, permissions);
-            // status controls comment editor
-            delete expandedTestCaseIds[expandedTestCaseIds.indexOf(testCaseId)];
-
             return false;
         });
     }
@@ -490,7 +414,10 @@ function updateTestCasesViaAPI(testCaseIds, updateQuery, testPlanId, permissions
             const testCaseRow = $(`.js-testcase-row[data-testcase-pk=${caseId}]`);
 
             // update internal data
+            sortkey = allTestCases[caseId].sortkey;
             allTestCases[caseId] = updatedTC;
+            // note: updatedTC doesn't have sortkey information
+            allTestCases[caseId].sortkey = sortkey;
 
             animate(testCaseRow, function() {
                 redrawSingleRow(caseId, testPlanId, permissions);
@@ -510,7 +437,12 @@ function toolbarEvents(testPlanId, permissions) {
     });
 
     $('.js-toolbar-filter-options li').click(function(ev) {
-        changeDropdownSelectedItem('.js-toolbar-filter-options', '#input-filter-button' , ev.target);
+        return changeDropdownSelectedItem(
+            '.js-toolbar-filter-options',
+            '#input-filter-button',
+            ev.target,
+            $('#toolbar-filter')
+        );
     });
 
     $('#toolbar-filter').on("keyup", function() {
@@ -523,13 +455,13 @@ function toolbarEvents(testPlanId, permissions) {
             filterBy,
             filterValue
         );
-
     });
 
     $('.js-toolbar-sort-options li').click(function(ev) {
         changeDropdownSelectedItem('.js-toolbar-sort-options', '#sort-button', ev.target);
 
         sortTestCases(Object.values(allTestCases), testPlanId, permissions);
+        return false;
     });
 
     //handle asc desc icon
@@ -599,10 +531,6 @@ function toolbarEvents(testPlanId, permissions) {
 
         updateTestCasesViaAPI(selectedCases, {case_status: ev.target.dataset.id},
                               testPlanId, permissions);
-        // status controls comment editor
-        selectedCases.forEach(function(caseId) {
-            delete expandedTestCaseIds[expandedTestCaseIds.indexOf(caseId)];
-        })
         return false;
     });
 
@@ -697,7 +625,7 @@ function toolbarEvents(testPlanId, permissions) {
         }
 
         for (let i = 0; i < selectedTestCases.length; i++) {
-            let status = allTestCases[selectedTestCases[i]].case_status_id;
+            let status = allTestCases[selectedTestCases[i]].case_status;
             if (!isTestCaseConfirmed(status)) {
                 alert($('#test_plan_pk').data('trans-cannot-create-testrun'));
                 return false;
@@ -710,23 +638,7 @@ function toolbarEvents(testPlanId, permissions) {
 }
 
 function isTestCaseConfirmed(status) {
-    return Number(status) === Number($('#test_plan_pk').data('testcasestatus-confirmed-pk'));
-}
-
-// on dropdown change update the label of the button and set new selected list item
-function changeDropdownSelectedItem(dropDownSelector, buttonSelector, target) {
-    $(`${buttonSelector}`)[0].innerHTML = target.innerText + '<span class="caret"></span>';
-
-    //remove selected class
-    $(`${dropDownSelector} li`).each(function(index, el) {
-        el.className = '';
-    });
-
-    // target is a tag
-    target.parentElement.className = 'selected';
-
-    // clear the text & the current filter
-    $('#toolbar-filter').val('').keyup().focus();
+    return confirmedStatuses.indexOf(Number(status)) > -1 ;
 }
 
 function sortTestCases(testCases, testPlanId, permissions, defaultSortBy = undefined) {
@@ -770,3 +682,27 @@ function getSelectedTestCases() {
     return tcIds;
 
 }
+
+function filterTestCasesByProperty(planId, testCases, filterBy, filterValue) {
+    // no input => show all rows
+    if (filterValue.trim().length === 0) {
+        $('.js-testcase-row').show();
+        return;
+    }
+
+    $('.js-testcase-row').hide();
+    if (filterBy === 'component' || filterBy === 'tag') {
+        let query = {plan: planId}
+        query[`${filterBy}__name__icontains`] = filterValue
+
+        jsonRPC('TestCase.filter', query, function(filtered) {
+            // hide again if a previous async request showed something else
+            $('.js-testcase-row').hide();
+            filtered.forEach(tc => $(`[data-testcase-pk=${tc.id}]`).show());
+        })
+    } else {
+        testCases.filter(function(tc){
+            return (tc[filterBy] && tc[filterBy].toString().toLowerCase().indexOf(filterValue) > -1)
+        }).forEach(tc => $(`[data-testcase-pk=${tc.id}]`).show());
+    }
+}
