@@ -5,38 +5,48 @@ from django.contrib.auth.models import Group, Permission
 
 def generate_output(output, permissions, group):
     """
-        Generates verbose output for added permissions
+    Generates verbose output for added permissions
     """
     if output:
         for perm in permissions:
-            output.write('%s.%s added to %s group' %
-                         (perm.content_type.app_label, perm.codename,
-                          group.name))
+            output.write(
+                "%s.%s added to %s group"
+                % (perm.content_type.app_label, perm.codename, group.name)
+            )
 
 
 def assign_default_group_permissions(output=None, refresh_all=False):
     """
-        Adds the default permissions for Administrator and Tester
-        groups!
+    Adds the default permissions for Administrator and Tester
+    groups!
     """
-    admin = Group.objects.get(name='Administrator')
+    admin = Group.objects.get(name="Administrator")
     if admin.permissions.count() == 0 or refresh_all:
-        perms_to_add = Permission.objects.exclude(
-            pk__in=admin.permissions.all())
+        perms_to_add = Permission.objects.exclude(pk__in=admin.permissions.all())
         admin.permissions.add(*perms_to_add)
         generate_output(output, perms_to_add, admin)
 
-    tester = Group.objects.get(name='Tester')
+    tester = Group.objects.get(name="Tester")
     tester_perms = tester.permissions.all()
     if tester_perms.count() == 0 or refresh_all:
         # apply all permissions for test case & product management
-        for app_name in ['bugs', 'django_comments', 'linkreference', 'management',
-                         'testcases', 'testplans', 'testruns', 'attachments']:
+        for app_name in [
+            "bugs",
+            "django_comments",
+            "linkreference",
+            "management",
+            "testcases",
+            "testplans",
+            "testruns",
+            "attachments",
+        ]:
             app_perms = Permission.objects.filter(
-                content_type__app_label__contains=app_name)
+                content_type__app_label__contains=app_name
+            )
             app_perms = app_perms.exclude(pk__in=tester_perms).exclude(
-                content_type__app_label='attachments',
-                codename='delete_foreign_attachments')
+                content_type__app_label="attachments",
+                codename="delete_foreign_attachments",
+            )
             tester.permissions.add(*app_perms)
             generate_output(output, app_perms, tester)
 
